@@ -72,7 +72,7 @@ KABC::AddresseeList GMXXXPort::importContacts( const QString& ) const
 {
   KABC::AddresseeList addrList;
 
-  QString fileName = KFileDialog::getOpenFileName( QDir::homeDirPath(), 
+  QString fileName = KFileDialog::getOpenFileName( ":xxport_gmx", 
                       GMX_FILESELECTION_STRING, 0 );
   if ( fileName.isEmpty() )
     return addrList;
@@ -115,6 +115,10 @@ KABC::AddresseeList GMXXXPort::importContacts( const QString& ) const
     addr->setGivenName(strList[2]);
     addr->setFamilyName(strList[3]);
     addr->setTitle(strList[4]);
+
+    if (addr->formattedName().isEmpty())
+	addr->setFormattedName(addr->realName());
+
     if (checkDateTime(strList[5],dt)) addr->setBirthday(dt);
     addr->setNote(strList[6]);
     if (checkDateTime(strList[7],dt)) addr->setRevision(dt);
@@ -122,7 +126,7 @@ KABC::AddresseeList GMXXXPort::importContacts( const QString& ) const
     // addr->xxx(strList[9]); Address_link_id 
     // addr->setCategory(strList[10]); Categories
     addrMap[strList[0]] = addr;
-    
+
     line = gmxStream.readLine();
   }
 
@@ -202,8 +206,7 @@ KABC::AddresseeList GMXXXPort::importContacts( const QString& ) const
 
 bool GMXXXPort::exportContacts( const KABC::AddresseeList &list, const QString& )
 {
-  KURL url = KFileDialog::getSaveURL( QDir::homeDirPath() + "/addressbook.gmx", 
-			GMX_FILESELECTION_STRING );
+  KURL url = KFileDialog::getSaveURL( ":xxport_gmx", GMX_FILESELECTION_STRING );
   if ( url.isEmpty() )
       return true;
 
