@@ -130,9 +130,6 @@ void KatePluginTabBarExtension::addView(Kate::MainWindow *win)
   if (toolbar) {
     connect(toolbar, SIGNAL( orientationChanged(Orientation) ),
         m_tabbar, SLOT( slotMoved(Orientation) ));
-
-    // workaround for wrong orientation, so do not disrupt the toolbar.
-    m_tabbar->slotMoved( toolbar->orientation() );
   }
 }
 
