@@ -94,43 +94,49 @@ KConfDialog::KConfDialog(KTimeMon *t)
 
     gl->addColSpacing(0, 10); gl->addColSpacing(9, 25);
 
-    QString colourLabels[2][3];
-    colourLabels[0][0] = i18n("Kernel:");
-    colourLabels[0][1] = i18n("User:");
-#if defined(USE_SOLARIS)
-    colourLabels[0][2] = i18n("Wait:");
-#else
-    colourLabels[0][2] = i18n("Nice:");
-#endif
+    QString cpuColourLabels[4];
+    cpuColourLabels[0] = i18n("Kernel:");
+    cpuColourLabels[1] = i18n("User:");
+    cpuColourLabels[2] = i18n("Nice:");
+    cpuColourLabels[3] = i18n("IOWait:");
 
-    colourLabels[1][0] = i18n("Used:");
-    colourLabels[1][1] = i18n("Buffers:");
-#if defined(USE_SOLARIS) || defined(__osf__)
-    colourLabels[1][2] = i18n("Kernel:");
-#else
-    colourLabels[1][2] = i18n("Cached:");
-#endif
-#
-    KColorButton **colourButtons[2][3] = { { &kernelCB, &userCB, &niceCB },
-                                           { &usedCB, &buffersCB, &cachedCB }};
-    for (i = 0; i < 2; i++) {
-        b = new QGroupBox((i ? i18n("Memory/Swapping")
-                             : i18n("CPU/Paging")), page);
-        gl->addMultiCellWidget(b, 4*i, 4*i+2, 0, 9);
+    QString memColourLabels[4];
+    memColourLabels[0] = i18n("Kernel:");
+    memColourLabels[1] = i18n("Used:");
+    memColourLabels[2] = i18n("Buffers:");
+    memColourLabels[3] = i18n("Cached:");
 
-        for (j = 0; j < 3; j++) {
-            l = new QLabel(colourLabels[i][j], page);
-            gl->addWidget(l, 4*i+1, 3*j+1, AlignVCenter | AlignRight);
+    KColorButton **cpuColourButtons[4] = { &kernelCB, &userCB, &niceCB, &iowaitCB };
+    b = new QGroupBox(i18n("CPU"), page);
+    gl->addMultiCellWidget(b, 0, 2, 0, 13);
+    
+    for (j = 0; j < 4; j++) {
+      l = new QLabel(cpuColourLabels[j], page);
+      gl->addWidget(l, 1, 3*j+1, AlignVCenter | AlignRight);
 
-            cb = *colourButtons[i][j] = new KColorButton(white, page);
-            gl->addWidget(cb, 4*i+1, 3*j+2, AlignCenter);
-
-            connect(cb, SIGNAL(changed(const QColor &)),
-                    this, SLOT(updateSampleWidget(const QColor &)));
-        }
+      cb = *cpuColourButtons[j] = new KColorButton(white, page);
+      gl->addWidget(cb, 1, 3*j+2, AlignCenter);
+      
+      connect(cb, SIGNAL(changed(const QColor &)),
+              this, SLOT(updateSampleWidget(const QColor &)));
     }
 
-    b = new QGroupBox(i18n("Swap/Background"), page);
+    KColorButton **memColourButtons[4] = { &mkernelCB, &usedCB, &buffersCB, &cachedCB };
+    b = new QGroupBox(i18n("Memory"), page);
+    gl->addMultiCellWidget(b, 4, 6, 0, 13);
+
+    for (j = 0; j < 4; j++) {
+      l = new QLabel(memColourLabels[j], page);
+      gl->addWidget(l, 5, 3*j+1, AlignVCenter | AlignRight);
+
+      cb = *memColourButtons[j] = new KColorButton(white, page);
+      gl->addWidget(cb, 5, 3*j+2, AlignCenter);
+      
+      connect(cb, SIGNAL(changed(const QColor &)),
+              this, SLOT(updateSampleWidget(const QColor &)));
+    }
+
+    b = new QGroupBox(i18n("Swap"), page);
     gl->addMultiCellWidget(b, 8, 10, 0, 6);
 
     l = new QLabel(i18n("Swap:"), page);
@@ -214,6 +220,8 @@ void KConfDialog::updateSampleWidget(const QColor &)
   sample->kernelColour = kernelCB->color();
   sample->userColour = userCB->color();
   sample->niceColour = niceCB->color();
+  sample->iowaitColour = iowaitCB->color();
+  sample->kernelColour = kernelCB->color();
   sample->cachedColour = cachedCB->color();
   sample->usedColour = usedCB->color();
   sample->buffersColour = buffersCB->color();
@@ -250,7 +258,9 @@ void KConfDialog::update()
   kernelCB->setColor(timemon->kernelColour);
   userCB->setColor(timemon->userColour);
   niceCB->setColor(timemon->niceColour);
+  iowaitCB->setColor(timemon->iowaitColour);
   buffersCB->setColor(timemon->buffersColour);
+  mkernelCB->setColor(timemon->mkernelColour);
   usedCB->setColor(timemon->usedColour);
   cachedCB->setColor(timemon->cachedColour);
   swapCB->setColor(timemon->swapColour);
