@@ -49,10 +49,12 @@ void KTimeMon::updateConfig(KConfDialog *d)
 {
     kernelColour = d->getKernelColour();
     userColour = d->getUserColour();
+    iowaitColour = d->getIOWaitColour();
     niceColour = d->getNiceColour();
     cachedColour = d->getCachedColour();
     usedColour = d->getUsedColour();
     buffersColour = d->getBuffersColour();
+    mkernelColour = d->getMKernelColour();
     swapColour = d->getSwapColour();
     bgColour = d->getBgColour();
 }
@@ -115,6 +117,7 @@ void KTimeMon::paintEvent(QPaintEvent *)
     }
 
     y = h - s.kernel; paintRect(x, y, b, s.kernel, kernelColour, &painter);
+    y -= s.iowait; paintRect(x, y, b, s.iowait, iowaitColour, &painter);
     y -= s.user; paintRect(x, y, b, s.user, userColour, &painter);
     y -= s.nice; paintRect(x, y, b, s.nice, niceColour, &painter);
 
@@ -127,7 +130,8 @@ void KTimeMon::paintEvent(QPaintEvent *)
         paintRect(x, 0, b, h, bgColour, &painter);
     }
 
-    y = h - s.used; paintRect(x, y, b, s.used, usedColour, &painter);
+    y = h - s.mkernel; paintRect(x, y, b, s.mkernel, mkernelColour, &painter);
+    y -= s.used; paintRect(x, y, b, s.used, usedColour, &painter);
     y -= s.buffers; paintRect(x, y, b, s.buffers, buffersColour, &painter);
     y -= s.cached; paintRect(x, y, b, s.cached, cachedColour, &painter);
 
@@ -185,8 +189,9 @@ KTimeMon::KTimeMon(const QString& configFile, Type type, int actions,
     : KPanelApplet(configFile, type, actions, parent, name, WRepaintNoErase), QToolTip(this),
     configDialog(0), bgProcess(0),
     kernelColour("red1"), userColour("blue"),
-    niceColour("yellow"), cachedColour("darkgreen"),
+    niceColour("yellow"), iowaitColour("darkgreen"),
     usedColour("blue1"), buffersColour("yellow"),
+    cachedColour("darkgreen"), mkernelColour("red1"),
     swapColour("cyan3"), bgColour(colorGroup().background())
 {
     mouseAction[0] = NOTHING;
@@ -214,10 +219,12 @@ KTimeMon::KTimeMon(const QString& configFile, Type type, int actions,
     kernelColour = conf->readColorEntry("KernelColour", &kernelColour);
     userColour = conf->readColorEntry("UserColour", &userColour);
     niceColour = conf->readColorEntry("NiceColour", &niceColour);
+    iowaitColour = conf->readColorEntry("IOWaitColour", &iowaitColour);
     cachedColour = conf->readColorEntry("CachedColour", &cachedColour);
     usedColour = conf->readColorEntry("UsedColour", &usedColour);
     buffersColour = conf->readColorEntry("BuffersColour", &buffersColour);
     swapColour = conf->readColorEntry("SwapColour", &swapColour);
+    mkernelColour = conf->readColorEntry("MKernelColour", &mkernelColour);
     bgColour = conf->readColorEntry("BgColour", &bgColour);
 
     vertical = conf->readBoolEntry("Vertical", true);
@@ -303,9 +310,11 @@ void KTimeMon::writeConfiguration()
     conf->writeEntry("KernelColour", kernelColour);
     conf->writeEntry("UserColour", userColour);
     conf->writeEntry("NiceColour", niceColour);
+    conf->writeEntry("IOWaitColour", iowaitColour);
     conf->writeEntry("CachedColour", cachedColour);
     conf->writeEntry("UsedColour", usedColour);
     conf->writeEntry("BuffersColour", buffersColour);
+    conf->writeEntry("MKernelColour", mkernelColour);
     conf->writeEntry("SwapColour", swapColour);
     conf->writeEntry("BgColour", bgColour);
     conf->writeEntry("Mode", true);
