@@ -1,10 +1,9 @@
 /***************************************************************************
-                          noatunInterface.h
-            this is the abstract class to access noatun from
+                          Interface to access Noatun
                              -------------------
     begin                : Mon Jan 15 21:09:00 MEZ 2001
     copyright            : (C) 2001-2002 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
@@ -37,25 +36,22 @@ class NoatunInterface : public PlayerInterface
 		void updateSlider();
 		void sliderStartDrag();
 		void sliderStopDrag();
-		void jumpToTime( int sec );
-		void play();
-		void pause();
+		void jumpToTime(int sec);
+		void playpause();
 		void stop();
 		void next();
 		void prev();
+		void volumeUp();
+		void volumeDown();
 		void dragEnterEvent(QDragEnterEvent* event);
 		void dropEvent(QDropEvent* event);
 		const QString getTrackTitle() const;
-		void appRegistered ( const QCString &appId );
-		void appRemoved ( const QCString &appId );
+		void appRegistered(const QCString &appId);
+		void appRemoved(const QCString &appId);
+		int playingStatus();
 
 		void myInit(void);
 
-	signals:
-		void newSliderPosition ( int, int );
-		void playerStarted(void);
-		void playerStopped(void);
-
 	private:
 		QTimer *mNoatunTimer;
 		int mTimerValue;
