@@ -1,10 +1,9 @@
 /***************************************************************************
-                          playerInterface.h
-            this is the abstract class to access any player from
+              this is the abstract class to access a player from
                              -------------------
     begin                : Mon Jan 15 21:09:00 MEZ 2001
     copyright            : (C) 2001 by Stefan Gehn
-    email                : sgehn@gmx.net
+    email                : metz {AT} gehn {DOT} net
  ***************************************************************************/
 
 /***************************************************************************
