@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 #include "plugin_babelfish.h"
 
@@ -166,7 +166,7 @@ PluginBabelFish::PluginBabelFish( QObject* parent, const char* name,
   m_menu->insert( m_it );
   m_menu->insert( new KAction( i18n("&Japanese to English"), 0,
                              this, SLOT(translateURL()),
-                             actionCollection(), "jp_en") );
+                             actionCollection(), "ja_en") );
   m_menu->insert( new KAction( i18n("&Korean to English"), 0,
                              this, SLOT(translateURL()),
                              actionCollection(), "ko_en") );
